.TITLE
                        ProPrint Sample Report 2
/

*
*   To produce this sample report:
*
*   First we define the FILEs which we are going to be reading.
*
*     The first .FILE section in this program defines the PRIMARY FILE. This
*     is the file which will be read from beginning to end in the 'SORTBY'
*     sequence specified to produce the report.

*     The SORTBY option for the primary FILE section below will logically
*     sequence the input file (using an index file) by the 'id_number' within
*     'department' fields.
*
*     Notice that the actual file definition is contained in the external
*     file 'sampemp.def' and included into the program using the '#include'
*     option in the FILE section.
*

.FILE EMP
#include sampemp.def
.SORTBY department | id_number
/

*
*     Any additional FILE sections defined in a program define a secondary
*     lookup file which is used to access related information stored in
*     other files.  After each primary file record is read, the
*     corresponding secondary file record is read.   The records are read
*     from the file according to the data relationship expressed in the
*     SEARCH/USING clause for the file. The SEARCH/USING clause can be read
*     as follows:  USING the data contained in the field(s) listed after the
*     '.USING' keyword, SEARCH for a record in the secondary file which
*     matches the data stored in the field(s) listed after the '.SEARCH'
*     keyword.

*     Each secondary file section requires a SORTBY clause so that
*     the secondary file will be indexed by the same field(s) as are
*     listed after the '.SEARCH' keyword.

*     For the secondary file section below, the records will be read
*     according to the value of the 'department' field in the primary record.
*     The search clause reads like this,  USING the data from the PRIMARY
*     records 'department' FIELD,   SEARCH the 'dept_code' FIELD of the
*     SECONDARY FILE for a matching record.
*

.FILE DEPT
SAMPDEPT.DAT | ASCII | 38
department         | INT  |  1|  4
department_name    | CHAR |  5| 30
department_manager | INT  | 35|  4
.SORTBY DEPT.department
.SEARCH DEPT.department  .USING EMP.department
/

*
*  Allow for SELECTing data from the file based on the 'department' FIELD.
*

.SELECT
EMP.department | "DEPARTMENT"
/

*
* Next we define any needed USERDATA fields, and our desired PROCESSing logic.
*
* We need a CHAR field to store each formatted name and sex field,
* in addition we need INTeger fields to store our total counts.
* Initialize the counters to zero.
*

.USERDATA
NAME_TEXT       | CHAR | 50
SEX_TEXT        | CHAR | 10
TOTAL_EMPLOYEES | INT  | 5 | 0
GRAND_TOTAL     | INT  | 6 | 0
/

*
*  Below we will define the special processing functions which will
*  enhance the appearace of the output report.
*  - PRODUCE A NAME IN THE FORMAT 'LAST_NAME, FIRST_NAME MI.'
*  - PRINT SEX WORD ie MALE or FEMALE using code in record M or F respectively
*  - COMPUTE FINAL TOTALS
*  - RESET COUNTERS AFTER PRINTING
*

.PROCESS MAKE_NAME_TEXT
   IF ( mid_initial == " " )
     SET NAME_TEXT= (RT)last_name |", "| (RT)first_name |"   "
   ELSE
     SET NAME_TEXT= (RT)last_name |", "| (RT)first_name |" "| mid_initial |"."
   ENDIF
/


.PROCESS MAKE_SEX_TEXT
    CONVERT SEX_TEXT| sex |DEFAULT="      "|"M"="MALE  "|"F"="FEMALE"
/


.PROCESS ACCUM_TOTALS
   COMPUTE TOTAL_EMPLOYEES = TOTAL_EMPLOYEES + 1
   COMPUTE GRAND_TOTAL = GRAND_TOTAL + 1
/
*
.PROCESS RESET_COUNTER
   COMPUTE TOTAL_EMPLOYEES = 0
/


*
*  The following section are the definitions for each report section
*

*
*  The report headings are defined in the '.HEADING' section. The HEADING
*  section (if defined) will be processed at the start of a report, and
*  then again at the top of each new page of a report.
*  This section defines two heading report lines.  Each line definition
*  consists of three consecutive program lines. (1) The first line contains
*  the Print Mask which contains any fixed text or field masks. A field
*  mask is a series of caret marks '^' indicating the desired placement
*  of field information from a file.  (2) The second line contains the
*  list of fields which correspond to field masks in the Print Mask.
*  If there are no fields being printed, then this line must be left blank.
*  (3) The third line of a line definition is the Line Spacing Control. This
*  indicates the vertical line spacing to be performed before and after
*  processing and printing the Print Mask. This is indicated as the number
*  of CR/LF characters to print.
*

.HEADING EMP.department
     COMPANY XYZ  REPORT FOR DEPARTMENT ^^^^ ^^^^^^^^^^^^^^^^^^^  Page: ^^^^^
EMP.department | DEPT.department_name | PAGE_NUM
1 | 2
   ID          NAME                  HIRE DATE     SEX     OCCUPATION

0 | 2
/

*
*  Below is the DETAIL section definition. This section will be process
*  once for each record which is read from the primary file.
*
*  There is one line defined in the DETAIL section below. It is defined in the
*  same manner as described above for a line definition. This section also
*  contains '.DO' subroutine calls which request that a PROCESS section
*  subroutine be executed. When the subroutine has completed, processing
*  will continue on the next line following the '.DO' command.
*

.DETAIL
.DO MAKE_NAME_TEXT
.DO MAKE_SEX_TEXT
 ^^^^^      ^^^^^^^^^^^^^^^^^^^^^^   ^^-^^-^@     ^^^^^^   ^^^^^^^^^^^^^^^^
id_number | NAME_TEXT | hire_date | SEX_TEXT | occupation
0 | 1
.DO ACCUM_TOTALS
/

*
*  The BREAK section is used to perform processing control breaks.
*  Following the '.BREAK' section title, you can indicate a field to
*  be monitored while reading records. When the contents of this field
*  changes value, from one record to the next, the contents of the BREAK
*  setion will be processed.
*
.BREAK EMP.department
   ^^^^^ TOTAL EMPLOYEES IN DEPARTMENT ^^^^ ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
TOTAL_EMPLOYEES | EMP.department | DEPT.department_name
2 | 2
.DO RESET_COUNTER
/

*
*  The TOTAL section will be processed after the last record has been read
*  from the primary file.
*

.TOTAL
      ^^^^^^ TOTAL EMPLOYEES PRINTED
GRAND_TOTAL
0 | 1
/
